.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: CC0-1.0

repology\_client.constants
==========================

.. automodule:: repology_client.constants
   :members:
